use crate::quantity::{Ohms, Quantity, Volts};

/// Given the resistance of the second resistor in a resistive voltage divider, calculate the resistance of the first resistor.
pub fn solve_r1(
    voltage_src: Volts<f32>,
    voltage_read: Volts<f32>,
    r2: Ohms<f32>,
) -> Ohms<f32> {
    Ohms(r2.value() * (voltage_src.value() / voltage_read.value() - 1.0))
}

/// Given the resistance of the first resistor in a resistive voltage divider, calculate the resistance of the second resistor.
pub fn solve_r2(
    voltage_src: Volts<f32>,
    voltage_read: Volts<f32>,
    r1: Ohms<f32>,
) -> Ohms<f32> {
    Ohms(r1.value() * (1.0  / (voltage_src.value() / voltage_read.value()) - 1.0))
}
